@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2008 by Ilya Kotov                                      *
+*   Copyright (C) 2008-2010 by Ilya Kotov                                 *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -25,14 +25,9 @@
 #include <QDialog>
 #include <QCompleter>
 #include <QAbstractItemView>
-
 #include <qmmpui/filedialog.h>
-
-#if QT_VERSION >= 0x040400
 #include <QFileSystemModel>
-#else
-#include <QDirModel>
-#endif
+
 
 class QmmpFileDialogImpl : public QDialog , private Ui::QmmpFileDialog
 {
@@ -61,13 +56,6 @@ signals:
     void filesAdded(const QStringList&);
 
 protected:
-
-#if QT_VERSION >= 0x040400
-    QFileSystemModel* m_model;
-#else
-    QDirModel* m_model;
-#endif
-
     virtual void hideEvent (QHideEvent *event);
 
 private slots:
@@ -75,6 +63,7 @@ private slots:
 
 private:
     int m_mode;
+    QFileSystemModel* m_model;
     void addToHistory(const QString &path);
     void addFiles(const QStringList &list);
     QStringList m_history;
@@ -93,12 +82,7 @@ public:
 
     QString pathFromIndex(const QModelIndex &index) const
     {
-#if QT_VERSION >= 0x040400
         const QFileSystemModel *dirModel = static_cast<const QFileSystemModel *>(model());
-#else
-        const QDirModel *dirModel = static_cast<const QDirModel *>(model());
-#endif
-
         QString currentLocation = dirModel->filePath(m_itemView->rootIndex());
         QString path = dirModel->filePath(index);
         if (path.startsWith(currentLocation))
@@ -116,11 +100,7 @@ public:
         QStringList parts;
         if (!path.startsWith(QDir::separator()))
         {
-#if QT_VERSION >= 0x040400
             const QFileSystemModel *dirModel = static_cast<const QFileSystemModel *>(model());
-#else
-            const QDirModel *dirModel = static_cast<const QDirModel *>(model());
-#endif
             QString currentLocation = QDir::toNativeSeparators(dirModel->filePath(m_itemView->rootIndex()));
             parts = QCompleter::splitPath(currentLocation);
         }
