@@ -45,19 +45,19 @@
 <context>
     <name>LyricsWindow</name>
     <message>
-        <location filename="../lyricswindow.cpp" line="63"/>
+        <location filename="../lyricswindow.cpp" line="64"/>
         <source>Done</source>
-        <translation type="unfinished"></translation>
+        <translation>Fertig</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="66"/>
+        <location filename="../lyricswindow.cpp" line="67"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="97"/>
+        <location filename="../lyricswindow.cpp" line="127"/>
         <source>Lyrics: %1 - %2</source>
-        <translation>Liedtext: %1 - %2</translation>
+        <translation>Liedtext: %1 – %2</translation>
     </message>
     <message>
         <location filename="../lyricswindow.ui" line="60"/>
@@ -65,12 +65,13 @@
         <translation>Keine Verbindung</translation>
     </message>
     <message>
-        <location filename="../lyricswindow.cpp" line="85"/>
+        <location filename="../lyricswindow.cpp" line="115"/>
         <source>Not found</source>
         <translation>Es kann kein Liedtext für dieses Stück gefunden werden.</translation>
     </message>
     <message>
         <location filename="../lyricswindow.cpp" line="96"/>
+        <location filename="../lyricswindow.cpp" line="126"/>
         <source>Receiving</source>
         <translation>Daten werden empfangen</translation>
     </message>
@@ -82,7 +83,7 @@
     <message>
         <location filename="../lyricswindow.ui" line="31"/>
         <source>Artist:</source>
-        <translation>Künstler:</translation>
+        <translation>Interpret:</translation>
     </message>
     <message>
         <location filename="../lyricswindow.ui" line="41"/>
