@@ -51,14 +51,14 @@ int TrackListObject::AddTrack(const QString &in0, bool in1)
         m_model->addFile(in0);
     int new_count = m_model->count();
     if(new_count == old_count)
-        return 0;
+        return 1;
     if(in1)
     {
         m_model->setCurrent(new_count-1);
         m_player->stop();
         m_player->play();
     }
-    return 1;
+    return 0;
 }
 
 void TrackListObject::DelTrack(int in0)
@@ -90,11 +90,11 @@ QVariantMap TrackListObject::GetMetadata(int in0)
         map.insert("artist", item->artist());
         map.insert("album", item->album());
         map.insert("tracknumber", item->track());
-        map.insert("time", item->length());
-        map.insert("mtime", item->length() * 1000);
+        map.insert("time", (quint32)item->length());
+        map.insert("mtime", (quint32)item->length() * 1000);
         map.insert("genre", item->genre());
         map.insert("comment", item->comment());
-        map.insert("year", item->year());
+        map.insert("year", item->year().toUInt());
     }
     return map;
 }
