@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 by Ilya Kotov                                      *
+ *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,7 +22,8 @@
 #include <QObject>
 #include <QRegExp>
 #include <QSettings>
-
+#include <QFileInfo>
+#include <QDir>
 #include <cdio/cdtext.h>
 #include <cdio/track.h>
 #include <cdio/cdda.h>
@@ -30,11 +31,11 @@
 #include <cdio/sector.h>
 #include <cdio/cd_types.h>
 #include <cdio/logging.h>
-
-#include <qmmp/constants.h>
+#include <cddb/cddb.h>
 #include <qmmp/buffer.h>
 #include <qmmp/output.h>
 #include <qmmp/recycler.h>
+#include <qmmp/qmmpsettings.h>
 
 #define CDDA_SECTORS 8
 
@@ -57,20 +58,10 @@ static void log_handler (cdio_log_level_t level, const char message[])
 
 // Decoder class
 
-DecoderCDAudio::DecoderCDAudio(QObject *parent, DecoderFactory *d, const QString &url, Output *o)
-        : Decoder(parent, d, o)
+DecoderCDAudio::DecoderCDAudio(const QString &url) : Decoder()
 {
-    m_inited = FALSE;
-    m_user_stop = FALSE;
-    m_output_buf = 0;
-    m_output_bytes = 0;
-    m_output_at = 0;
-    m_bks = 0;
-    m_done = FALSE;
-    m_finish = FALSE;
     m_bitrate = 0;
-    m_seekTime = -1.0;
-    m_totalTime = 0.0;
+    m_totalTime = 0;
     m_first_sector = -1;
     m_last_sector  = -1;
     m_current_sector  = -1;
@@ -81,10 +72,12 @@ DecoderCDAudio::DecoderCDAudio(QObject *parent, DecoderFactory *d, const QString
 
 DecoderCDAudio::~DecoderCDAudio()
 {
-    deinit();
-    if (m_output_buf)
-        delete [] m_output_buf;
-    m_output_buf = 0;
+    m_bitrate = 0;
+    if (m_cdio)
+    {
+        cdio_destroy(m_cdio);
+        m_cdio = 0;
+    }
 }
 
 QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
@@ -92,7 +85,7 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
     //read settings
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     int cd_speed = settings.value("cdaudio/speed", 0).toInt();
-    bool use_cd_text = settings.value("cdaudio/cdtext", TRUE).toBool();
+    bool use_cd_text = settings.value("cdaudio/cdtext", true).toBool();
     QList <CDATrack> tracks;
     cdio_log_set_handler(log_handler); //setup cdio log handler
     CdIo_t *cdio = 0;
@@ -101,7 +94,7 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
         device_path = settings.value("device").toString();
     if (device_path.isEmpty() || device_path == "/")
     {
-        char **cd_drives = cdio_get_devices_with_cap(0, CDIO_FS_AUDIO, TRUE); //get drive list with CDA disks
+        char **cd_drives = cdio_get_devices_with_cap(0, CDIO_FS_AUDIO, true); //get drive list with CDA disks
         // open first audio capable cd drive
         if (cd_drives && *cd_drives)
         {
@@ -154,6 +147,7 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
         cdio = 0;
         return tracks;
     }
+    bool use_cddb = true;
     //fill track list
     for (int i = first_track_number; i <= last_track_number; ++i)
     {
@@ -178,80 +172,174 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
             t.info.setMetaData(Qmmp::TITLE, QString::fromLocal8Bit(cdtext->field[CDTEXT_TITLE]));
             t.info.setMetaData(Qmmp::ARTIST, QString::fromLocal8Bit(cdtext->field[CDTEXT_PERFORMER]));
             t.info.setMetaData(Qmmp::GENRE, QString::fromLocal8Bit(cdtext->field[CDTEXT_GENRE]));
+            use_cddb = false;
         }
         else
             t.info.setMetaData(Qmmp::TITLE, QString("CDA Track %1").arg(i, 2, 10, QChar('0')));
         tracks  << t;
     }
     qDebug("DecoderCDAudio: found %d audio tracks", tracks.size());
+
+    use_cddb = use_cddb && settings.value("cdaudio/use_cddb", false).toBool();
+    if(use_cddb)
+    {
+        qDebug("DecoderCDAudio: reading CDDB...");
+        cddb_conn_t *cddb_conn = cddb_new ();
+        cddb_disc_t *cddb_disc = NULL;
+        cddb_track_t *cddb_track = NULL;
+        lba_t lba;
+        if (!cddb_conn)
+            qWarning ("DecoderCDAudio: unable to create cddb connection");
+        else
+        {
+            cddb_cache_disable (cddb_conn); //disable libcddb cache, use own cache implementation instead
+            settings.beginGroup("cdaudio");
+            cddb_set_server_name (cddb_conn, settings.value("cddb_server", "freedb.org").toByteArray());
+            cddb_set_server_port (cddb_conn, settings.value("cddb_port", 8880).toInt());
+
+            if (QmmpSettings::instance()->isProxyEnabled())
+            {
+                QUrl proxy = QmmpSettings::instance()->proxy();
+                cddb_http_proxy_enable (cddb_conn);
+                cddb_set_http_proxy_server_name (cddb_conn, proxy.host().toAscii ());
+                cddb_set_http_proxy_server_port (cddb_conn, proxy.port());
+                if(QmmpSettings::instance()->useProxyAuth())
+                {
+                    cddb_set_http_proxy_username (cddb_conn, proxy.userName().toAscii());
+                    cddb_set_http_proxy_password (cddb_conn, proxy.password().toAscii());
+                }
+            }
+            else if (settings.value("cddb_http", false).toBool())
+            {
+                cddb_http_enable (cddb_conn);
+                cddb_set_http_path_query (cddb_conn, settings.value("cddb_path").toByteArray());
+            }
+            settings.endGroup();
+
+            cddb_disc = cddb_disc_new ();
+            lba = cdio_get_track_lba (cdio, CDIO_CDROM_LEADOUT_TRACK);
+            cddb_disc_set_length (cddb_disc, FRAMES_TO_SECONDS (lba));
+
+            for (int i = first_track_number; i <= last_track_number; ++i)
+            {
+                cddb_track = cddb_track_new ();
+                cddb_track_set_frame_offset (cddb_track, cdio_get_track_lba (cdio, i));
+                cddb_disc_add_track (cddb_disc, cddb_track);
+            }
+
+            cddb_disc_calc_discid (cddb_disc);
+            qDebug ("DecoderCDAudio: disc id = %x", cddb_disc_get_discid (cddb_disc));
+            uint id = cddb_disc_get_discid (cddb_disc);
+
+            int matches = 0;
+            if(readFromCache(&tracks, id))
+                qDebug("DecoderCDAudio: using local cddb cache");
+            else if ((matches = cddb_query (cddb_conn, cddb_disc)) == -1)
+            {
+
+                qWarning ("DecoderCDAudio: unable to query the CDDB server, error: %s",
+                          cddb_error_str (cddb_errno(cddb_conn)));
+            }
+            else if (!matches)
+                qDebug ("DecoderCDAudio: no CDDB info found");
+            else
+            {
+                cddb_read(cddb_conn, cddb_disc);
+                if (cddb_errno (cddb_conn) != CDDB_ERR_OK)
+                {
+                    qWarning ("DecoderCDAudio: unable to read the CDDB info: %s",
+                              cddb_error_str (cddb_errno(cddb_conn)));
+                }
+                else
+                {
+                    for (int i = first_track_number; i <= last_track_number; ++i)
+                    {
+                        cddb_track_t *cddb_track = cddb_disc_get_track (cddb_disc, i - 1);
+                        int t = i - first_track_number;
+                        tracks[t].info.setMetaData(Qmmp::ARTIST,
+                                                   QString::fromUtf8(cddb_track_get_artist(cddb_track)));
+                        tracks[t].info.setMetaData(Qmmp::TITLE,
+                                                   QString::fromUtf8(cddb_track_get_title(cddb_track)));
+                        tracks[t].info.setMetaData(Qmmp::GENRE,
+                                                   QString::fromUtf8(cddb_disc_get_genre(cddb_disc)));
+                        tracks[t].info.setMetaData(Qmmp::ALBUM,
+                                                   QString::fromUtf8(cddb_disc_get_title(cddb_disc)));
+                    }
+                    saveToCache(tracks,  id);
+                }
+            }
+        }
+        if (cddb_disc)
+            cddb_disc_destroy (cddb_disc);
+
+        if (cddb_conn)
+            cddb_destroy (cddb_conn);
+    }
+
     cdio_destroy(cdio);
     cdio = 0;
     return tracks;
 }
 
+void DecoderCDAudio::saveToCache(QList <CDATrack> tracks,  uint disc_id)
+{
+    QString path = QFileInfo(Qmmp::configFile()).absoluteDir().path();
+    QDir dir(path);
+    if(!dir.exists("cddbcache"))
+        dir.mkdir("cddbcache");
+    dir.cd("cddbcache");
+    path = dir.absolutePath() + QString("/%1").arg(disc_id, 0, 16);
+    QSettings settings(path, QSettings::IniFormat);
+    settings.clear();
+    settings.setValue("count", tracks.size());
+    for(int i = 0; i < tracks.size(); ++i)
+    {
+        CDATrack track = tracks[i];
+        QMap<Qmmp::MetaData, QString> meta = track.info.metaData();
+        settings.setValue(QString("artist%1").arg(i), meta[Qmmp::ARTIST]);
+        settings.setValue(QString("title%1").arg(i), meta[Qmmp::TITLE]);
+        settings.setValue(QString("genre%1").arg(i), meta[Qmmp::GENRE]);
+        settings.setValue(QString("album%1").arg(i), meta[Qmmp::ALBUM]);
+    }
+}
+
+bool DecoderCDAudio::readFromCache(QList <CDATrack> *tracks, uint disc_id)
+{
+    QString path = QFileInfo(Qmmp::configFile()).absoluteDir().path();
+    path += QString("/cddbcache/%1").arg(disc_id, 0, 16);
+    if(!QFile::exists(path))
+        return false;
+    QSettings settings(path, QSettings::IniFormat);
+    int count = settings.value("count").toInt();
+    if(count != tracks->count())
+        return false;
+    for(int i = 0; i < count; ++i)
+    {
+        (*tracks)[i].info.setMetaData(Qmmp::ARTIST, settings.value(QString("artist%1").arg(i)).toString());
+        (*tracks)[i].info.setMetaData(Qmmp::TITLE, settings.value(QString("title%1").arg(i)).toString());
+        (*tracks)[i].info.setMetaData(Qmmp::GENRE, settings.value(QString("genre%1").arg(i)).toString());
+        (*tracks)[i].info.setMetaData(Qmmp::ALBUM, settings.value(QString("album%1").arg(i)).toString());
+    }
+    return true;
+}
+
 qint64 DecoderCDAudio::calculateTrackLength(lsn_t startlsn, lsn_t endlsn)
 {
     return ((endlsn - startlsn + 1) * 1000) / 75;
 }
 
-void DecoderCDAudio::stop()
-{
-    m_user_stop = TRUE;
-}
-
-
-void DecoderCDAudio::flush(bool final)
-{
-    ulong min = final ? 0 : m_bks;
-
-    while ((! m_done && ! m_finish) && m_output_bytes > min)
-    {
-        output()->recycler()->mutex()->lock ();
-
-        while ((! m_done && ! m_finish) && output()->recycler()->full())
-        {
-            mutex()->unlock();
-            output()->recycler()->cond()->wait(output()->recycler()->mutex());
-            mutex()->lock ();
-            m_done = m_user_stop;
-        }
-
-        if (m_user_stop || m_finish)
-        {
-            m_inited = FALSE;
-            m_done = TRUE;
-        }
-        else
-        {
-            m_output_bytes -= produceSound(m_output_buf, m_output_bytes, m_bitrate, 2);
-            m_output_at = m_output_bytes;
-        }
-
-        if (output()->recycler()->full())
-            output()->recycler()->cond()->wakeOne();
-
-        output()->recycler()->mutex()->unlock();
-    }
-}
-
-
 bool DecoderCDAudio::initialize()
 {
-    m_bks = Buffer::size();
-    m_inited = m_user_stop = m_done = m_finish = FALSE;
     m_bitrate = 0;
-    m_seekTime = -1.0;
-    m_totalTime = 0.0;
+    m_totalTime = 0;
     //extract track from url
     int track_number = m_url.section("#", -1).toInt();
     track_number = qMax(track_number, 1);
-    if (!m_output_buf) //output buffer
-        m_output_buf = new char[globalBufferSize];
     QList <CDATrack> tracks = DecoderCDAudio::generateTrackList(QUrl(m_url).path()); //generate track list
     if (tracks.isEmpty())
     {
         qWarning("DecoderCDAudio: initialize failed");
-        return FALSE;
+        return false;
     }
     //find track by number
     int track_at = -1;
@@ -264,7 +352,7 @@ bool DecoderCDAudio::initialize()
     if (track_at < 0)
     {
         qWarning("DecoderCDAudio: invalid track number");
-        return FALSE;
+        return false;
     }
 
     if (QUrl(m_url).path().isEmpty() || QUrl(m_url).path() == "/") //try default path from config
@@ -275,7 +363,7 @@ bool DecoderCDAudio::initialize()
 
     if (QUrl(m_url).path() == "/")
     {
-        char **cd_drives = cdio_get_devices_with_cap(0, CDIO_FS_AUDIO, TRUE); //get drive list with CDA disks
+        char **cd_drives = cdio_get_devices_with_cap(0, CDIO_FS_AUDIO, true); //get drive list with CDA disks
         // open first audio capable cd drive
         if (cd_drives && *cd_drives)
         {
@@ -284,14 +372,14 @@ bool DecoderCDAudio::initialize()
             {
                 qWarning("DecoderCDAudio: failed to open CD.");
                 cdio_free_device_list(cd_drives);
-                return FALSE;
+                return false;
             }
             qDebug("DecoderCDAudio: found cd audio capable drive \"%s\"", *cd_drives);
         }
         else
         {
             qWarning("DecoderCDAudio: unable to find cd audio drive.");
-            return FALSE;
+            return false;
         }
         if (cd_drives && *cd_drives) //free device list
             cdio_free_device_list(cd_drives);
@@ -302,124 +390,58 @@ bool DecoderCDAudio::initialize()
         if (!m_cdio)
         {
             qWarning("DecoderCDAudio: failed to open CD.");
-            return FALSE;
+            return false;
         }
         qDebug("DecoderCDAudio: using cd audio capable drive \"%s\"", QUrl(m_url).path().toAscii().constData());
     }
-    configure(44100, 2, 16);
+    configure(44100, 2, Qmmp::PCM_S16LE);
     m_bitrate = 1411;
     m_totalTime = tracks[track_at].info.length() * 1000;
     m_first_sector = tracks[track_at].first_sector;
     m_current_sector = tracks[track_at].first_sector;
     m_last_sector = tracks[track_at].last_sector;
-    stateHandler()->dispatch(tracks[track_at].info.metaData()); //send metadata
-    m_inited = TRUE;
+    StateHandler::instance()->dispatch(tracks[track_at].info.metaData()); //send metadata
     qDebug("DecoderCDAudio: initialize succes");
-    return TRUE;
+    return true;
 }
 
 
 qint64 DecoderCDAudio::totalTime()
 {
-    if (! m_inited)
-        return 0;
-
     return m_totalTime;
 }
 
+int DecoderCDAudio::bitrate()
+{
+    return m_bitrate;
+}
+
+qint64 DecoderCDAudio::read(char *audio, qint64 maxSize)
+{
+    long len = 0;
+    lsn_t secorts_to_read = qMin(CDDA_SECTORS, (m_last_sector - m_current_sector + 1));
+    if(secorts_to_read * CDIO_CD_FRAMESIZE_RAW > maxSize)
+    {
+        qWarning("DecoderCDAudio: buffer is too small");
+        return 0;
+    }
+    if (secorts_to_read <= 0)
+        len = 0;
+    else
+    {
+        if (cdio_read_audio_sectors(m_cdio, audio,
+                                    m_current_sector, secorts_to_read) != DRIVER_OP_SUCCESS)
+            len = -1;
+        else
+        {
+            len = secorts_to_read * CDIO_CD_FRAMESIZE_RAW;
+            m_current_sector += secorts_to_read;
+        }
+    }
+    return len;
+}
 
 void DecoderCDAudio::seek(qint64 pos)
 {
-    m_seekTime = pos;
-}
-
-
-void DecoderCDAudio::deinit()
-{
-    m_inited = m_user_stop = m_done = m_finish = FALSE;
-    m_bitrate = 0;
-    if (m_cdio)
-    {
-        cdio_destroy(m_cdio);
-        m_cdio = 0;
-    }
-}
-
-void DecoderCDAudio::run()
-{
-    long len = 0;
-    mutex()->lock ();
-    if (!m_inited)
-    {
-        mutex()->unlock();
-        return;
-    }
-    mutex()->unlock();
-
-    while (!m_done && !m_finish)
-    {
-        mutex()->lock ();
-
-        if (m_seekTime >= 0.0)
-        {
-            m_current_sector = m_first_sector + m_seekTime * 75 / 1000;
-            m_seekTime = -1.0;
-        }
-
-        lsn_t secorts_to_read = qMin(CDDA_SECTORS, (m_last_sector - m_current_sector + 1));
-        if (secorts_to_read <= 0)
-            len = 0;
-        else
-        {
-            if (cdio_read_audio_sectors(m_cdio, m_output_buf + m_output_at,
-                                        m_current_sector, secorts_to_read) != DRIVER_OP_SUCCESS)
-                len = -1;
-            else
-            {
-                len = secorts_to_read * CDIO_CD_FRAMESIZE_RAW;
-                m_current_sector += secorts_to_read;
-            }
-        }
-        if (len > 0)
-        {
-            m_output_at += len;
-            m_output_bytes += len;
-
-            if (output())
-                flush();
-        }
-        else if (len == 0)
-        {
-            flush(TRUE);
-
-            if (output())
-            {
-                output()->recycler()->mutex()->lock ();
-                // end of stream
-                while (! output()->recycler()->empty() && ! m_user_stop)
-                {
-                    output()->recycler()->cond()->wakeOne();
-                    mutex()->unlock();
-                    output()->recycler()->cond()->wait(output()->recycler()->mutex());
-                    mutex()->lock ();
-                }
-                output()->recycler()->mutex()->unlock();
-            }
-            m_done = TRUE;
-            m_finish = !m_user_stop;
-        }
-        else
-        {
-            qWarning("DecoderCDAudio: Error while decoding stream, disk to be corrupted");
-            m_finish = TRUE;
-        }
-        mutex()->unlock();
-    }
-    mutex()->lock ();
-
-    if (m_finish)
-        finish();
-
-    mutex()->unlock();
-    deinit();
+    m_current_sector = m_first_sector + pos * 75 / 1000;
 }
