@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,43 +42,43 @@ extern "C"{
 }
 #include <qmmp/decoder.h>
 
+#define INPUT_BUFFER_SIZE 16384
+
 class DecoderFFmpeg : public Decoder
 {
 public:
-    DecoderFFmpeg(QObject *, DecoderFactory *, Output *, const QString &);
+    DecoderFFmpeg(const QString &, QIODevice *i);
     virtual ~DecoderFFmpeg();
 
     // Standard Decoder API
     bool initialize();
     qint64 totalTime();
-    void seek(qint64);
-    void stop();
+    int bitrate();
+    qint64 read(char *audio, qint64 maxSize);
+    void seek(qint64 time);
 
-private:
-    // thread run function
-    void run();
-    // helper functions
-    void flush(bool = FALSE);
-    void deinit();
-    void ffmpeg_out(int size);
-    bool inited, user_stop;
-
-    // output buffer
-    char *output_buf;
-    qint64 output_bytes, output_at;
+private:    
+    //helper functions
+    void fillBuffer();
+    qint64 ffmpeg_decode(uint8_t *audio);
 
     AVFormatContext *ic;
     AVCodecContext *c;
-    uint wma_st_buff, wma_idx, wma_idx2;
-    uint8_t *wma_outbuf;
-
-    unsigned int bks;
-    bool done, m_finish;
-    long freq, bitrate;
-    int chan;
-    qint64 output_size;
-    qint64 m_totalTime, seekTime;
+    uint wma_st_buff, wma_idx2;
+    int m_bitrate, wma_idx;
     QString m_path;
+    bool m_skip;
+    qint64 m_totalTime;
+
+    AVPacket m_pkt;
+    AVPacket m_temp_pkt;
+    ByteIOContext m_stream;
+    uint8_t *m_output_buf;
+    qint64 m_output_at;
+    uchar m_input_buf[INPUT_BUFFER_SIZE + FF_INPUT_BUFFER_PADDING_SIZE];
+
+    int64_t m_seekTime;
+    qint64  m_skipBytes;    
 };
 
 
