@@ -26,7 +26,7 @@
 #include <libmodplug/sndfile.h>
 
 #include "settingsdialog.h"
-#include "detailsdialog.h"
+#include "modplugmetadatamodel.h"
 #include "decoder_modplug.h"
 #include "archivereader.h"
 #include "decodermodplugfactory.h"
@@ -45,13 +45,13 @@ bool DecoderModPlugFactory::supports(const QString &source) const
     << ".xmgz" << ".itz"  << /*".itr" <<*/ ".itgz" << ".dmf" << ".umx" << ".it" << ".669"
     << ".xm" << ".mtm" << ".psm" << ".ft2";
     if (lExtList.contains(lExt))
-        return TRUE;
-    return FALSE;
+        return true;
+    return false;
 }
 
 bool DecoderModPlugFactory::canDecode(QIODevice *) const
 {
-    return FALSE;
+    return false;
 }
 
 const DecoderProperties DecoderModPlugFactory::properties() const
@@ -64,25 +64,24 @@ const DecoderProperties DecoderModPlugFactory::properties() const
     properties.description = tr("ModPlug Files");
     //properties.contentType = ;
     properties.shortName = "modplug";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = TRUE;
-    properties.noInput = TRUE;
+    properties.hasAbout = true;
+    properties.hasSettings = true;
+    properties.noInput = true;
     properties.protocols = "file";
     return properties;
 }
 
-Decoder *DecoderModPlugFactory::create(QObject *parent, QIODevice *input,
-                                       Output *output, const QString &path)
+Decoder *DecoderModPlugFactory::create(const QString &path, QIODevice *input)
 {
     Q_UNUSED(input);
-    return new DecoderModPlug(parent, this, output, path);
+    return new DecoderModPlug(path);
 }
 
 QList<FileInfo *> DecoderModPlugFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
     QList <FileInfo*> list;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    if (!useMetaData || settings.value("UseFileName", FALSE).toBool())
+    if (!useMetaData || settings.value("UseFileName", false).toBool())
     {
         list << new FileInfo(fileName);
         list.at(0)->setMetaData(Qmmp::TITLE, fileName.section('/',-1));
@@ -106,7 +105,7 @@ QList<FileInfo *> DecoderModPlugFactory::createPlayList(const QString &fileName,
         file.close();
     }
     CSoundFile* soundFile = new CSoundFile();
-    soundFile->Create((uchar*) buffer.data(), buffer.size());
+    soundFile->Create((uchar*) buffer.data(), buffer.size()+1);
     list << new FileInfo(fileName);
     list.at(0)->setLength((int) soundFile->GetSongTime());
     list.at(0)->setMetaData(Qmmp::TITLE, QString::fromUtf8(soundFile->GetTitle()));
@@ -115,11 +114,9 @@ QList<FileInfo *> DecoderModPlugFactory::createPlayList(const QString &fileName,
     return list;
 }
 
-QObject* DecoderModPlugFactory::showDetails(QWidget *parent, const QString &path)
+MetaDataModel* DecoderModPlugFactory::createMetaDataModel(const QString &path, QObject *parent)
 {
-    DetailsDialog *d = new DetailsDialog(parent, path);
-    d -> show();
-    return d;
+    return new ModPlugMetaDataModel(path, parent);
 }
 
 void DecoderModPlugFactory::showSettings(QWidget *parent)
@@ -148,4 +145,4 @@ QTranslator *DecoderModPlugFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderModPlugFactory)
+Q_EXPORT_PLUGIN2(modplug,DecoderModPlugFactory)
