@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -40,24 +40,24 @@ bool DecoderSndFileFactory::supports(const QString &source) const
             (source.right(4).toLower() == ".sph") ||
             (source.right(3).toLower() == ".sf") ||
             (source.right(4).toLower() == ".voc"))
-        return TRUE;
+        return true;
     else if (source.right(4).toLower() == ".wav")
     {
         //try top open the file
         SF_INFO snd_info;
         SNDFILE *sndfile = sf_open(source.toLocal8Bit(), SFM_READ, &snd_info);
         if (!sndfile)
-            return FALSE;
+            return false;
         sf_close (sndfile);
         sndfile = 0;
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 bool DecoderSndFileFactory::canDecode(QIODevice *) const
 {
-    return FALSE;
+    return false;
 }
 
 const DecoderProperties DecoderSndFileFactory::properties() const
@@ -68,18 +68,16 @@ const DecoderProperties DecoderSndFileFactory::properties() const
     properties.description = tr("PCM Files");
     //properties.contentType = "";
     properties.shortName = "sndfile";
-    properties.hasAbout = TRUE;
-    properties.hasSettings = FALSE;
-    properties.noInput = TRUE;
+    properties.hasAbout = true;
+    properties.hasSettings = false;
+    properties.noInput = true;
     properties.protocols = "file";
     return properties;
 }
 
-Decoder *DecoderSndFileFactory::create(QObject *parent, QIODevice *input,
-                                       Output *output, const QString &path)
+Decoder *DecoderSndFileFactory::create(const QString &path, QIODevice *)
 {
-    Q_UNUSED(input);
-    return new DecoderSndFile(parent, this, output, path);
+    return new DecoderSndFile(path);
 }
 
 QList<FileInfo *> DecoderSndFileFactory::createPlayList(const QString &fileName, bool useMetaData)
@@ -119,10 +117,8 @@ QList<FileInfo *> DecoderSndFileFactory::createPlayList(const QString &fileName,
     return list;
 }
 
-QObject* DecoderSndFileFactory::showDetails(QWidget *parent, const QString &path)
+MetaDataModel* DecoderSndFileFactory::createMetaDataModel(const QString&, QObject *)
 {
-    Q_UNUSED(parent);
-    Q_UNUSED(path);
     return 0;
 }
 
@@ -147,4 +143,4 @@ QTranslator *DecoderSndFileFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(DecoderSndFileFactory)
+Q_EXPORT_PLUGIN2(sndfile, DecoderSndFileFactory)
