@@ -27,57 +27,62 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="24"/>
+        <location filename="../settingsdialog.ui" line="33"/>
         <source>Device Settings</source>
         <translation>Параметры устройства</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="36"/>
+        <location filename="../settingsdialog.ui" line="45"/>
         <source>Audio device</source>
         <translation>Аудио устройство</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="48"/>
+        <location filename="../settingsdialog.ui" line="57"/>
         <source>Mixer</source>
         <translation>Микшер</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="63"/>
+        <location filename="../settingsdialog.ui" line="72"/>
         <source>Mixer card:</source>
         <translation>Карта микшера:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="73"/>
+        <location filename="../settingsdialog.ui" line="82"/>
         <source>Mixer device:</source>
         <translation>Устройство микшера:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="90"/>
+        <location filename="../settingsdialog.ui" line="99"/>
         <source>Advanced Settings</source>
         <translation>Дополнительные настройки</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="102"/>
+        <location filename="../settingsdialog.ui" line="111"/>
         <source>Soundcard</source>
         <translation>Звуковая карта</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="108"/>
+        <location filename="../settingsdialog.ui" line="117"/>
         <source>Buffer time (ms):</source>
         <translation>Время буферизации (мс):</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="144"/>
+        <location filename="../settingsdialog.ui" line="153"/>
         <source>Period time (ms):</source>
         <translation>Время периода (мс):</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="209"/>
+        <source>Use snd_pcm_pause function</source>
+        <translation>Использовать функцию snd_pcm_pause</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>ALSA Plugin Settings</source>
         <translation>Настройки модуля ALSA</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="180"/>
+        <location filename="../settingsdialog.ui" line="189"/>
         <source>Use mmap access</source>
         <translation>Использовать доступ mmap</translation>
     </message>
