@@ -23,9 +23,8 @@
 #include <QtGlobal>
 #include <QDir>
 #include <QSettings>
-
 #include "outputjack.h"
-#include <qmmp/constants.h>
+#include <qmmp/audioparameters.h>
 #include <qmmp/buffer.h>
 #include <qmmp/visual.h>
 
@@ -33,7 +32,7 @@
 #include <string.h>
 
 OutputJACK::OutputJACK(QObject *parent)
-        : Output(parent), m_inited(FALSE), m_configure(FALSE)
+        : Output(parent), m_inited(false), m_configure(false)
 {
     JACK_Init();
 }
@@ -43,24 +42,26 @@ OutputJACK::~OutputJACK()
     uninitialize();
 }
 
-void OutputJACK::configure(quint32 freq, int chan, int prec)
+void OutputJACK::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
     qDebug("OutputJACK: configure");
-    if(JACK_Open(&jack_device, prec, (unsigned long *)&freq, chan))
+    if(JACK_Open(&jack_device, AudioParameters::sampleSize(format)*8, (unsigned long *)&freq, chan))
     {
-        m_configure = FALSE;
+        m_configure = false;
+        m_inited = false;
         return;
     }
     else
-        m_configure = TRUE;
-    Output::configure(freq, chan, prec);
+        m_configure = true;
+    m_inited = true;
+    Output::configure(freq, chan, format);
     qDebug("OutputJACK: configure end");
 }
 
 bool OutputJACK::initialize()
 {
-    m_inited = FALSE;
-    m_configure = FALSE;
+    m_inited = false;
+    m_configure = false;
     jack_options_t options = JackNoStartServer;
     jack_status_t status;
     jack_client_t *client = jack_client_open ("test_qmmp", options, &status, NULL);
@@ -71,11 +72,11 @@ bool OutputJACK::initialize()
         {
             qDebug("Unable to connect to JACK server.");
         }
-        return FALSE;
+        return false;
     }
     jack_client_close (client);
-    m_inited = TRUE;
-    return TRUE;
+    m_inited = true;
+    return true;
 }
 
 qint64 OutputJACK::latency()
@@ -86,7 +87,7 @@ qint64 OutputJACK::latency()
 qint64 OutputJACK::writeAudio(unsigned char *data, qint64 maxSize)
 {
     if(!m_configure)
-        return -1;
+         return -1;
     m = JACK_Write(jack_device, (unsigned char*)data, maxSize);
     if (!m)
         usleep(2000);
