@@ -28,8 +28,8 @@ const OutputProperties OutputJACKFactory::properties() const
 {
     OutputProperties properties;
     properties.name = tr("JACK Plugin");
-    properties.hasAbout = TRUE;
-    properties.hasSettings = FALSE;
+    properties.hasAbout = true;
+    properties.hasSettings = false;
     properties.shortName = "jack";
     return properties;
 }
@@ -63,4 +63,4 @@ QTranslator *OutputJACKFactory::createTranslator(QObject *parent)
     return translator;
 }
 
-Q_EXPORT_PLUGIN(OutputJACKFactory)
+Q_EXPORT_PLUGIN2(jack,OutputJACKFactory)
