@@ -30,6 +30,7 @@ class QTranslator;
 class Decoder;
 class Output;
 class FileInfo;
+class MetaDataModel;
 
 /*! @brief Helper class to store input plugin properies.
  * @author Ilya Kotov <forkotov02@hotmail.ru>
@@ -42,10 +43,10 @@ public:
      */
     DecoderProperties()
     {
-        hasAbout = FALSE;
-        hasSettings = FALSE;
-        noInput = FALSE;
-        noOutput = FALSE;
+        hasAbout = false;
+        hasSettings = false;
+        noInput = false;
+        noOutput = false;
 
     }
     QString name;        /*!< Input plugin full name */
@@ -54,10 +55,10 @@ public:
     QString description; /*!< File filter description */
     QString contentType; /*!< Supported content types */
     QString protocols;   /*!< Supported protocols. Should be empty if plugin uses stream input. */
-    bool hasAbout;       /*!< Should be \b true if plugin has about dialog, otherwise returns \b false */
-    bool hasSettings;    /*!< Should be \b true if plugin has settings dialog, otherwise returns \b false */
-    bool noInput;        /*!< Should be \b true if plugin has own input, otherwise returns \b false */
-    bool noOutput;       /*!< Should be \b true if plugin has own output, otherwise returns \b false */
+    bool hasAbout;       /*!< Should be \b true if plugin has about dialog, otherwise \b false */
+    bool hasSettings;    /*!< Should be \b true if plugin has settings dialog, otherwise \b false */
+    bool noInput;        /*!< Should be \b true if plugin has own input, otherwise \b false */
+    bool noOutput;       /*!< Should be \b true if plugin has own output, otherwise \b false */
 };
 /*! @brief Input plugin interface (decoder factory).
  * @author Ilya Kotov <forkotov02@hotmail.ru>
@@ -83,13 +84,10 @@ public:
     virtual const DecoderProperties properties() const = 0;
     /*!
      * Creates decoder object.
-     * @param parent Parent object.
-     * @param input Input data (if required)
-     * @param output Output object (if required)
      * @param path File path
+     * @param input Input data (if required)
      */
-    virtual Decoder *create(QObject *parent, QIODevice *input = 0,
-                            Output *output = 0, const QString &path = QString()) = 0;
+    virtual Decoder *create(const QString &path , QIODevice *input = 0) = 0;
     /*!
      * Extracts metadata and audio information from file \b path and returns a list of FileInfo items.
      * One file may contain several playlist items (for example: cda disk or flac with embedded cue)
@@ -98,12 +96,12 @@ public:
      */
     virtual QList<FileInfo *> createPlayList(const QString &fileName, bool useMetaData) = 0;
     /*!
-     * Shows details dialog.
-     * @param parent Parent widget.
+     * Creats metadata object, which provides full access to file tags.
      * @param path File path.
-     * @return Dialog pointer.
+     * @param parent Parent object.
+     * @return MetaDataModel pointer.
      */
-    virtual QObject* showDetails(QWidget *parent, const QString &path) = 0;
+    virtual MetaDataModel* createMetaDataModel(const QString &path, QObject *parent = 0) = 0;
     /*!
      * Shows settings dialog.
      * @param parent Parent widget.
