@@ -113,9 +113,10 @@ bool QmmpAudioEngine::enqueue(InputSource *source)
 
     if(!source->url().contains("://"))
         factory = Decoder::findByPath(source->url());
-    if(!factory && source->ioDevice())
+    if(!factory)
+        factory = Decoder::findByMime(source->contentType());
+    if(!factory && source->ioDevice() && source->url().contains("://")) //ignore content of local files
         factory = Decoder::findByContent(source->ioDevice());
-    //TODO mimetype
     if(!factory && source->url().contains("://"))
         factory = Decoder::findByProtocol(source->url().section("://",0,0));
     if(!factory)
@@ -174,9 +175,19 @@ void QmmpAudioEngine::setEQEnabled(bool on)
 
 void QmmpAudioEngine::addEffect(EffectFactory *factory)
 {
+    foreach(Effect *effect, m_effects)
+    {
+        if(effect->factory() == factory)
+        {
+            qWarning("QmmpAudioEngine: effect %s already exists",
+                     qPrintable(factory->properties().shortName));
+            return;
+        }
+    }
     if(m_output && m_output->isRunning())
     {
         Effect *effect = factory->create();
+        effect->setFactory(factory);
         effect->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
         if(effect->audioParameters() == m_ap)
         {
@@ -195,10 +206,13 @@ void QmmpAudioEngine::addEffect(EffectFactory *factory)
 void QmmpAudioEngine::removeEffect(EffectFactory *factory)
 {
     Effect *effect = 0;
-    foreach(effect, m_effects)
+    foreach(Effect *e, m_effects)
     {
-        if(effect->factory() == factory)
+        if(e->factory() == factory)
+        {
+            effect = e;
             break;
+        }
     }
     if(!effect)
         return;
