@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2008 by Ilya Kotov                                      *
+*   Copyright (C) 2008-2010 by Ilya Kotov                                 *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -18,15 +18,15 @@
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
-#include "filedialog.h"
-
+#include <QFile>
 #include <QSettings>
 #include <QTranslator>
 #include <QApplication>
 #include <QPluginLoader>
 #include <QMetaObject>
+#include <QLibrary>
 #include <qmmp/qmmp.h>
-
+#include "filedialog.h"
 #include "qtfiledialog.h"
 
 
@@ -34,7 +34,7 @@ FileDialog* FileDialog::_instance = 0;
 
 QMap<QString,FileDialogFactory*> FileDialog::factories = QMap<QString,FileDialogFactory*>();
 
-FileDialog::FileDialog() : QObject(), m_initialized(FALSE)
+FileDialog::FileDialog() : QObject(), m_initialized(false)
 {
     m_lastDir = 0;
 }
@@ -179,6 +179,24 @@ void FileDialog::registerExternalFactories()
             qApp->installTranslator(fct->createTranslator(qApp));
         }
     }
+#ifndef Q_OS_WIN32
+#if (QT_VERSION >= 0x040500 && QT_VERSION < 0x040600)
+    //load native kde dialog
+    QStringList paths;
+    paths << "/usr/lib/kde4/kio_file.so";
+    paths << "/usr/lib64/kde4/kio_file.so";
+    paths << "/usr/local/kde4/lib/kde4/kio_file.so";
+    foreach(QString path, paths)
+    {
+        if(QFile::exists(path))
+        {
+            QLibrary *l = new QLibrary(path, qApp);
+            l->load();
+            break;
+        }
+    }
+#endif
+#endif
 }
 
 bool FileDialog::registerFactory(FileDialogFactory *factory)
