@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,25 +20,27 @@
 #include <QSettings>
 #include <QDir>
 
-#include <qmmp/decoder.h>
+#include <qmmp/metadatamanager.h>
+#include "metadataformatter.h"
 #include "playlistsettings.h"
 #include "playlistitem.h"
 
 PlayListItem::PlayListItem() : AbstractPlaylistItem(), m_flag(FREE)
 {
     m_info = 0;
+    m_selected = false;
+    m_current = false;
 }
 
 PlayListItem::PlayListItem(FileInfo *info) : AbstractPlaylistItem(), m_flag(FREE)
 {
-    m_selected = FALSE;
-    m_current = FALSE;
+    m_selected = false;
+    m_current = false;
     m_info = info;
 
     setMetaData(info->metaData());
     setMetaData(Qmmp::URL, m_info->path());
     setLength(m_info->length());
-    readMetadata();
 }
 
 PlayListItem::~PlayListItem()
@@ -85,21 +87,27 @@ void PlayListItem::updateMetaData(const QMap <Qmmp::MetaData, QString> &metaData
 
 void PlayListItem::updateTags()
 {
-    if (url().startsWith("http://"))
-        return;
     if (m_info)
     {
         delete m_info;
         m_info = 0;
     }
-    m_info = Decoder::createPlayList(url()).at(0);
-    setMetaData(m_info->metaData());
-    setMetaData(Qmmp::URL, m_info->path());
-    readMetadata();
+    QList <FileInfo *> list =  MetaDataManager::instance()->createPlayList(url());
+    if(!list.isEmpty() && !list.at(0)->path().contains("://"))
+    {
+        m_info = list.at(0);
+        setMetaData(m_info->metaData());
+        setMetaData(Qmmp::URL, m_info->path());
+        readMetadata();
+    }
+    while(list.size() > 1)
+        delete list.takeLast();
 }
 
-const QString PlayListItem::text() const
+const QString PlayListItem::text()
 {
+    if(m_title.isEmpty())
+        readMetadata();
     return m_title;
 }
 
@@ -110,16 +118,8 @@ void PlayListItem::setText(const QString &title)
 
 void PlayListItem::readMetadata()
 {
-    m_title = PlaylistSettings::instance()->format();
-    m_title = printTag(m_title, "%p", artist());
-    m_title = printTag(m_title, "%a", album());
-    m_title = printTag(m_title, "%t", title());
-    m_title = printTag(m_title, "%n", track());
-    m_title = printTag(m_title, "%g", genre());
-    m_title = printTag(m_title, "%c", comment());
-    m_title = printTag(m_title, "%f", url().section('/',-1));
-    m_title = printTag(m_title, "%F", url());
-    m_title = printTag(m_title, "%y", year());
+    MetaDataFormatter f(PlaylistSettings::instance()->format());
+    m_title = f.parse(metaData());
     //TODO rewrite this
     if (m_title.isEmpty())
     {
@@ -134,30 +134,3 @@ void PlayListItem::readMetadata()
     if (PlaylistSettings::instance()->convertTwenty())
         m_title.replace("%20", " ");
 }
-
-QString PlayListItem::printTag(QString str, QString regExp, QString tagStr)
-{
-    QString format = PlaylistSettings::instance()->format();
-    if (!tagStr.isEmpty())
-        str.replace(regExp, tagStr);
-    else
-    {
-        //remove unused separators
-        int regExpPos = str.indexOf(regExp);
-        if (regExpPos < 0)
-            return str;
-        int nextPos = str.indexOf("%", regExpPos + 1);
-        if (nextPos < 0)
-        {
-            //last separator
-            regExpPos = format.lastIndexOf(regExp);
-            nextPos = format.lastIndexOf("%", regExpPos - 1);
-            QString lastSep = format.right (format.size() - nextPos - 2);
-            str.remove(lastSep);
-            str.remove(regExp);
-        }
-        else
-            str.remove ( regExpPos, nextPos - regExpPos);
-    }
-    return str;
-}
