@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright(C) 2006-2009 by Ilya Kotov                                  *
+ *   Copyright(C) 2006-2010 by Ilya Kotov                                  *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,23 +27,19 @@
 #include <QApplication>
 #include <QTimer>
 #include <QSettings>
-#include <QMessageBox>
 #include <QBuffer>
-
+#include <QMetaType>
 #include <time.h>
-
-#include <qmmp/decoder.h>
-#include <qmmp/decoderfactory.h>
-
+#include <qmmp/metadatamanager.h>
 #include "playlistparser.h"
 #include "playlistformat.h"
 #include "fileloader.h"
-#include "playlistmodel.h"
 #include "playlistitem.h"
 #include "playstate.h"
+#include "detailsdialog.h"
 #include "playlistsettings.h"
+#include "playlistmodel.h"
 
-#include <QMetaType>
 
 #define INVALID_ROW -1
 
@@ -68,27 +64,22 @@ void TagUpdater::updateTag()
     }
 }
 
-
-PlayListModel::PlayListModel(QObject *parent)
+PlayListModel::PlayListModel(const QString &name, QObject *parent)
         : QObject(parent) , m_selection()
 {
     qsrand(time(0));
+    m_name = name;
     m_shuffle = 0;
     m_total_length = 0;
     m_current = 0;
-    m_block_update_signals = false;
     is_repeatable_list = false;
     m_play_state = new NormalPlayState(this);
-    readSettings();
 }
 
 PlayListModel::~PlayListModel()
 {
-    writeSettings();
     clear();
     delete m_play_state;
-    //qDeleteAll(m_registered_pl_formats);
-
     foreach(GuardedFileLoader l,m_running_loaders)
     {
         if (!l.isNull())
@@ -97,22 +88,51 @@ PlayListModel::~PlayListModel()
             l->wait();
         }
     }
-    delete PlaylistSettings::instance();
 }
 
-void PlayListModel::load(PlayListItem *item)
+QString PlayListModel::name() const
+{
+    return m_name;
+}
+
+void PlayListModel::setName(const QString &name)
+{
+    if(m_name != name)
+    {
+        m_name = name;
+        emit nameChanged(name);
+    }
+}
+
+void PlayListModel::add(PlayListItem *item)
 {
     if (m_items.isEmpty())
         m_currentItem = item;
 
     m_total_length += item->length();
     m_items << item;
+    m_current = m_items.indexOf(m_currentItem);
 
     if (m_items.size() == 1)
-        emit firstAdded();
+        emit firstAdded();    
+    emit listChanged();
+}
 
-    if (!m_block_update_signals)
-        emit listChanged();
+void PlayListModel::add(QList <PlayListItem *> items)
+{
+    if(items.isEmpty())
+        return;
+    if (m_items.isEmpty())
+        m_currentItem = items.at(0);
+
+    foreach(PlayListItem *item, items)
+        m_total_length += item->length();
+    m_items << items;
+
+    if (m_items.size() == items.size())
+        emit firstAdded();
+    m_current = m_items.indexOf(m_currentItem);
+    emit listChanged();
 }
 
 int PlayListModel::count()
@@ -122,10 +142,16 @@ int PlayListModel::count()
 
 PlayListItem* PlayListModel::currentItem()
 {
-    if (m_items.isEmpty())
+    return m_items.isEmpty() ? 0 : m_items.at(qMin(m_items.size() - 1, m_current));
+}
+
+PlayListItem* PlayListModel::nextItem()
+{
+    if(isShuffle() || m_items.isEmpty() || !isEmptyQueue())
         return 0;
-    else
-        return m_items.at(qMin(m_items.size() - 1, m_current));
+    if(m_current < m_items.size() - 1)
+        return m_items.at(m_current + 1);
+    return 0;
 }
 
 PlayListItem* PlayListModel::item(int row) const
@@ -141,20 +167,24 @@ int PlayListModel::currentRow()
 bool PlayListModel::setCurrent(int c)
 {
     if (c > count()-1 || c < 0)
-        return FALSE;
+        return false;
     m_current = c;
     m_currentItem = m_items.at(c);
     emit currentChanged();
     emit listChanged();
-    return TRUE;
+    return true;
 }
 
-
 bool PlayListModel::next()
 {
+    if (!isEmptyQueue())
+    {
+        setCurrentToQueued();
+        return true;
+    }
+
     if (isFileLoaderRunning())
         m_play_state->prepare();
-
     return m_play_state->next();
 }
 
@@ -162,8 +192,7 @@ bool PlayListModel::previous()
 {
     if (isFileLoaderRunning())
         m_play_state->prepare();
-
-    return m_play_state->previous();//)
+    return m_play_state->previous();
 }
 
 void PlayListModel::clear()
@@ -203,7 +232,7 @@ void PlayListModel::clear()
 void PlayListModel::clearSelection()
 {
     for (int i = 0; i<m_items.size(); ++i)
-        m_items.at(i)->setSelected(FALSE);
+        m_items.at(i)->setSelected(false);
     emit listChanged();
 }
 
@@ -218,10 +247,19 @@ QList <QString> PlayListModel::getTitles(int b,int l)
 QList <QString> PlayListModel::getTimes(int b,int l)
 {
     QList <QString> m_times;
-    for (int i = b;(i < b + l) &&(i < m_items.size()); ++i)
-        m_times << QString("%1").arg(m_items.at(i)->length() /60) +":"
-        +QString("%1").arg(m_items.at(i)->length() %60/10) +
-        QString("%1").arg(m_items.at(i)->length() %60%10);
+    int d = 0;
+    QString str;
+    for (int i = b; (i < b + l) && (i < m_items.size()); ++i)
+    {
+        d = m_items.at(i)->length();
+        if(d > 3600)
+            str += QString("%1:%2").arg(d/3600).arg(d%3600/60, 2, 10, QChar('0'));
+        else
+            str += QString("%1").arg(d%3600/60);
+        str += QString(":%1").arg(d%60, 2, 10, QChar('0'));
+        m_times << str;
+        str.clear();
+    }
     return m_times;
 }
 
@@ -233,6 +271,16 @@ bool PlayListModel::isSelected(int row)
     return false;
 }
 
+bool PlayListModel::contains(const QString &url)
+{
+    foreach (PlayListItem *item, m_items)
+    {
+        if(item->url() == url)
+            return true;
+    }
+    return false;
+}
+
 void PlayListModel::setSelected(int row, bool yes)
 {
     if (m_items.count() > row && row >= 0)
@@ -277,6 +325,12 @@ void PlayListModel::removeAt (int i)
     }
 }
 
+void PlayListModel::removeItem (PlayListItem *item)
+{
+    if(m_items.contains(item))
+        removeAt (m_items.indexOf(item));
+}
+
 void PlayListModel::removeSelection(bool inverted)
 {
     int i = 0;
@@ -332,7 +386,7 @@ void PlayListModel::invertSelection()
 void PlayListModel::selectAll()
 {
     for (int i = 0; i<m_items.size(); ++i)
-        m_items.at(i)->setSelected(TRUE);
+        m_items.at(i)->setSelected(true);
     emit listChanged();
 }
 
@@ -342,126 +396,24 @@ void PlayListModel::showDetails()
     {
         if (m_items.at(i)->isSelected())
         {
-            if (!QFile::exists(m_items.at(i)->url()))
-            {
-                PlayListItem *item = m_items.at(i);
-                QString str;
-                str.append(tr("Url:") + " %1\n");
-                str.append(tr("Title:") + " %2\n");
-                str.append(tr("Artist:") + " %3\n");
-                str.append(tr("Album:") + " %4\n");
-                str.append(tr("Genre:") + " %5\n");
-                str.append(tr("Comment:") + " %6");
-                str = str.arg(item->url())
-                      .arg(item->title().isEmpty() ? item->text() : item->title())
-                      .arg(item->artist())
-                      .arg(item->album())
-                      .arg(item->genre())
-                      .arg(item->comment());
-                QMessageBox::information(0, m_items.at(i)->url(), str);
-                return;
-            }
-
-            DecoderFactory *fact = Decoder::findByPath(m_items.at(i)->url());
-            if (fact)
-            {
-                QObject* o = fact->showDetails(0, m_items.at(i)->url());
-                if (o)
-                {
-                    TagUpdater *updater = new TagUpdater(o,m_items.at(i));
-                    m_editing_items.append(m_items.at(i));
-                    connect(updater, SIGNAL(destroyed(QObject *)),SIGNAL(listChanged()));
-                }
-            }
+            QDialog *d = new DetailsDialog(m_items.at(i)); //TODO set parent widget
+            TagUpdater *updater = new TagUpdater(d, m_items.at(i));
+            m_editing_items.append(m_items.at(i));
+            connect(updater, SIGNAL(destroyed(QObject *)),SIGNAL(listChanged()));
+            d->show();
             return;
         }
     }
 }
 
-void PlayListModel::readSettings()
-{
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_current = settings.value("Playlist/current",0).toInt();
-
-    QString line, param, value;
-    int s;
-    QList <FileInfo *> infoList;
-    QFile file(QDir::homePath() +"/.qmmp/playlist.txt");
-    file.open(QIODevice::ReadOnly);
-    QByteArray array = file.readAll();
-    file.close();
-    QBuffer buffer(&array);
-    buffer.open(QIODevice::ReadOnly);
-    while (!buffer.atEnd())
-    {
-        line = QString::fromUtf8(buffer.readLine()).trimmed();
-        if ((s = line.indexOf("=")) < 0)
-            continue;
-
-        param = line.left(s);
-        value = line.right(line.size() - s - 1);
-
-        if (param == "file")
-            infoList << new FileInfo(value);
-        else if (infoList.isEmpty())
-            continue;
-        else if (param == "title")
-            infoList.last()->setMetaData(Qmmp::TITLE, value);
-        else if (param == "artist")
-            infoList.last()->setMetaData(Qmmp::ARTIST, value);
-        else if (param == "album")
-            infoList.last()->setMetaData(Qmmp::ALBUM, value);
-        else if (param == "comment")
-            infoList.last()->setMetaData(Qmmp::COMMENT, value);
-        else if (param == "genre")
-            infoList.last()->setMetaData(Qmmp::GENRE, value);
-        else if (param == "year")
-            infoList.last()->setMetaData(Qmmp::YEAR, value);
-        else if (param == "track")
-            infoList.last()->setMetaData(Qmmp::TRACK, value);
-        else if (param == "length")
-            infoList.last()->setLength(value.toInt());
-    }
-    buffer.close();
-    if (m_current > infoList.count() - 1)
-        m_current = 0;
-    m_block_update_signals = TRUE;
-    foreach(FileInfo *info, infoList)
-    load(new PlayListItem(info));
-    m_block_update_signals = FALSE;
-    if(!m_items.isEmpty())
-        m_currentItem = m_items.at(m_current);
-    doCurrentVisibleRequest();
-}
-
-void PlayListModel::writeSettings()
-{
-    QFile file(QDir::homePath() +"/.qmmp/playlist.txt");
-    file.open(QIODevice::WriteOnly);
-    foreach(PlayListItem* m, m_items)
-    {
-        file.write(QString("file=%1").arg(m->url()).toUtf8() +"\n");
-        file.write(QString("title=%1").arg(m->title()).toUtf8() +"\n");
-        file.write(QString("artist=%1").arg(m->artist()).toUtf8() +"\n");
-        file.write(QString("album=%1").arg(m->album()).toUtf8() +"\n");
-        file.write(QString("comment=%1").arg(m->comment()).toUtf8() +"\n");
-        file.write(QString("genre=%1").arg(m->genre()).toUtf8() +"\n");
-        file.write(QString("year=%1").arg(m->year()).toUtf8() +"\n");
-        file.write(QString("track=%1").arg(m->track()).toUtf8() +"\n");
-        file.write(QString("length=%1").arg(m->length()).toUtf8() +"\n");
-    }
-    file.close();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("Playlist/current", m_current);
-}
-
 void PlayListModel::addFile(const QString& path)
 {
     if (path.isEmpty())
         return;
-    QList <FileInfo *> playList = Decoder::createPlayList(path, PlaylistSettings::instance()->useMetadata());
+    QList <FileInfo *> playList =
+            MetaDataManager::instance()->createPlayList(path, PlaylistSettings::instance()->useMetadata());
     foreach(FileInfo *info, playList)
-    emit load(new PlayListItem(info));
+        add(new PlayListItem(info));
 
     m_play_state->prepare();
 }
@@ -471,7 +423,7 @@ FileLoader * PlayListModel::createFileLoader()
     FileLoader* f_loader = new FileLoader(this);
 // f_loader->setStackSize(20 * 1024 * 1024);
     m_running_loaders << f_loader;
-    connect(f_loader,SIGNAL(newPlayListItem(PlayListItem*)),this,SLOT(load(PlayListItem*)),Qt::QueuedConnection);
+    connect(f_loader,SIGNAL(newPlayListItem(PlayListItem*)),SLOT(add(PlayListItem*)),Qt::QueuedConnection);
     connect(f_loader,SIGNAL(finished()),this,SLOT(preparePlayState()));
     connect(f_loader,SIGNAL(finished()),f_loader,SLOT(deleteLater()));
     return f_loader;
@@ -514,7 +466,7 @@ void PlayListModel::addFileList(const QStringList &l)
 
 bool PlayListModel::setFileList(const QStringList & l)
 {
-    bool model_cleared = FALSE;
+    bool model_cleared = false;
     foreach(QString str,l)
     {
         QFileInfo f_info(str);
@@ -523,7 +475,7 @@ bool PlayListModel::setFileList(const QStringList & l)
             if (!model_cleared)
             {
                 clear();
-                model_cleared = TRUE;
+                model_cleared = true;
             }
             if (f_info.isDir())
                 addDirectory(str);
@@ -592,8 +544,6 @@ void PlayListModel::moveItems(int from, int to)
     }
 }
 
-
-
 int PlayListModel::topmostInSelection(int row)
 {
     if (row == 0)
@@ -663,14 +613,7 @@ void PlayListModel::addToQueue()
 {
     QList<PlayListItem*> selected_items = getSelectedItems();
     foreach(PlayListItem* file,selected_items)
-    {/*
-                if(isQueued(file))
-                    m_queued_songs.removeAt(m_queued_songs.indexOf(file));
-                else
-                    m_queued_songs.append(file);
-                 */
         setQueued(file);
-    }
     emit listChanged();
 }
 
@@ -680,7 +623,6 @@ void PlayListModel::setQueued(PlayListItem* file)
         m_queued_songs.removeAt(m_queued_songs.indexOf(file));
     else
         m_queued_songs.append(file);
-
     emit listChanged();
 }
 
@@ -722,6 +664,8 @@ void PlayListModel::reverseList()
 
 // First we'll implement bundle of static compare procedures
 // to sort items in different ways
+
+//by title
 static bool _titleLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return QString::localeAwareCompare (s1->title(), s2->title()) < 0;
@@ -731,7 +675,27 @@ static bool _titleGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return QString::localeAwareCompare (s1->title(), s2->title()) > 0;
 }
+//by album
+static bool _albumLessComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QString::localeAwareCompare (s1->album(), s2->album()) < 0;
+}
 
+static bool _albumGreaterComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QString::localeAwareCompare (s1->album(), s2->album()) > 0;
+}
+//by artist
+static bool _artistLessComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QString::localeAwareCompare (s1->artist(), s2->artist()) < 0;
+}
+
+static bool _artistGreaterComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QString::localeAwareCompare (s1->artist(), s2->artist()) > 0;
+}
+//by path
 static bool _pathAndFilenameLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return QString::localeAwareCompare (s1->url(), s2->url()) < 0;
@@ -741,7 +705,7 @@ static bool _pathAndFilenameGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return QString::localeAwareCompare (s1->url(), s2->url()) > 0;
 }
-
+//by file name
 static bool _filenameLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
     QFileInfo i_s1(s1->url());
@@ -755,7 +719,7 @@ static bool _filenameGreaterComparator(PlayListItem* s1,PlayListItem* s2)
     QFileInfo i_s2(s2->url());
     return QString::localeAwareCompare (i_s1.baseName(), i_s2.baseName()) > 0;
 }
-
+//by date
 static bool _dateLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return s1->year().toInt() < s2->year().toInt();
@@ -765,7 +729,7 @@ static bool _dateGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return s1->year().toInt() > s2->year().toInt();
 }
-
+//by track
 static bool _trackLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return s1->track().toInt() < s2->track().toInt();
@@ -794,6 +758,14 @@ void PlayListModel::doSort(int sort_mode,QList<PlayListItem*>& list_to_sort)
         compareLessFunc = _titleLessComparator;
         compareGreaterFunc = _titleGreaterComparator;
         break;
+    case ALBUM:
+        compareLessFunc = _albumLessComparator;
+        compareGreaterFunc = _albumGreaterComparator;
+        break;
+    case ARTIST:
+        compareLessFunc = _artistLessComparator;
+        compareGreaterFunc = _artistGreaterComparator;
+        break;
     case FILENAME:
         compareLessFunc = _filenameLessComparator;
         compareGreaterFunc = _filenameGreaterComparator;
@@ -864,14 +836,11 @@ void PlayListModel::prepareForShufflePlaying(bool val)
         m_play_state = new NormalPlayState(this);
 
     m_shuffle = val;
-
-    emit shuffleChanged(val);
 }
 
 void PlayListModel::prepareForRepeatablePlaying(bool val)
 {
     is_repeatable_list = val;
-    emit repeatableListChanged(val);
 }
 
 void PlayListModel::doCurrentVisibleRequest()
@@ -880,13 +849,6 @@ void PlayListModel::doCurrentVisibleRequest()
     emit listChanged();
 }
 
-void PlayListModel::setUpdatesEnabled(bool yes)
-{
-    m_block_update_signals = !yes;
-    if (yes)
-        emit listChanged();
-}
-
 void PlayListModel::loadPlaylist(const QString &f_name)
 {
     PlaylistFormat* prs = PlaylistParser::instance()->findByPath(f_name);
@@ -944,9 +906,9 @@ bool PlayListModel::isFileLoaderRunning() const
 {
     foreach(FileLoader* l,m_running_loaders)
     if (l && l->isRunning())
-        return TRUE;
+        return true;
 
-    return FALSE;
+    return false;
 }
 
 void PlayListModel::preparePlayState()
@@ -954,46 +916,28 @@ void PlayListModel::preparePlayState()
     m_play_state->prepare();
 }
 
-bool PlayListModel::convertUnderscore()
+void PlayListModel::removeInvalidItems()
 {
-    return PlaylistSettings::instance()->convertUnderscore();
+    foreach(PlayListItem *item, m_items)
+    {
+        bool ok = false;
+        if(!item->url().contains("://"))
+            ok = MetaDataManager::instance()->supports(item->url());
+        else
+            ok = MetaDataManager::instance()->protocols().contains(item->url().section("://",0,0));
+        if(!ok)
+            removeItem(item);
+    }
 }
 
-bool PlayListModel::convertTwenty()
+void PlayListModel::removeDuplicates()
 {
-    return PlaylistSettings::instance()->convertTwenty();
-}
-
-bool PlayListModel::useMetadata()
-{
-    return PlaylistSettings::instance()->useMetadata();
-}
-
-const QString PlayListModel::format() const
-{
-    return PlaylistSettings::instance()->format();
-}
-
-void PlayListModel::setConvertUnderscore(bool yes)
-{
-    PlaylistSettings::instance()->setConvertUnderscore(yes);
-    emit settingsChanged();
-}
-
-void PlayListModel::setConvertTwenty(bool yes)
-{
-    PlaylistSettings::instance()->setConvertTwenty(yes);
-    emit settingsChanged();
-}
-
-void PlayListModel::setUseMetadata(bool yes)
-{
-    PlaylistSettings::instance()->setUseMetadata(yes);
-    emit settingsChanged();
-}
-
-void PlayListModel::setFormat(const QString &format)
-{
-    PlaylistSettings::instance()->setFormat(format);
-    emit settingsChanged();
+    for(int i = 0; i < m_items.size(); ++i)
+    {
+        for(int j = i + 1; j < m_items.size(); ++j)
+        {
+            if(m_items.at(i)->url() == m_items.at(j)->url())
+                removeItem(m_items.at(j));
+        }
+    }
 }
