@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,14 +26,14 @@
 #include <QMenu>
 #include <QUrl>
 #include <QApplication>
-
+#include <QHelpEvent>
+#include <QTimer>
 #include <qmmpui/playlistitem.h>
 #include <qmmpui/playlistmodel.h>
 #include <qmmpui/mediaplayer.h>
-
-#include "textscroller.h"
 #include "listwidget.h"
 #include "skin.h"
+#include "popupwidget.h"
 #include "playlist.h"
 
 #define INVALID_ROW -1
@@ -41,8 +41,9 @@
 ListWidget::ListWidget(QWidget *parent)
         : QWidget(parent)
 {
-    m_update = FALSE;
-    m_skin = Skin::getPointer();
+    m_update = false;
+    m_skin = Skin::instance();
+    m_popupWidget = 0;
     loadColors();
     m_menu = new QMenu(this);
     m_scroll_direction = NONE;
@@ -52,11 +53,15 @@ ListWidget::ListWidget(QWidget *parent)
     connect (m_player, SIGNAL(repeatableChanged(bool)), SLOT(updateList()));
     m_first = 0;
     m_rows = 0;
-    m_scroll = FALSE;
-    m_select_on_release = FALSE;
+    m_scroll = false;
+    m_select_on_release = false;
     readSettings();
     connect(m_skin, SIGNAL(skinChanged()), this, SLOT(updateSkin()));
     setAcceptDrops(true);
+    setMouseTracking(true);
+    m_timer = new QTimer(this);
+    m_timer->setInterval(50);
+    connect(m_timer, SIGNAL(timeout()), SLOT(autoscroll()));
 }
 
 
@@ -66,25 +71,30 @@ ListWidget::~ListWidget()
 void ListWidget::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    QString fontname = settings.value("PlayList/Font").toString();
-    if (!fontname.isEmpty())
-        m_font.fromString(fontname);
-    m_show_protocol = settings.value ("PlayList/show_protocol", FALSE).toBool();
-    m_show_number = settings.value ("PlayList/show_numbers", TRUE).toBool();
-
+    m_font.fromString(settings.value("PlayList/Font", QApplication::font().toString()).toString());
+    m_show_protocol = settings.value ("PlayList/show_protocol", false).toBool();
+    m_show_number = settings.value ("PlayList/show_numbers", true).toBool();
+    bool show_popup = settings.value("PlayList/show_popup", false).toBool();
 
     if (m_update)
     {
         delete m_metrics;
         m_metrics = new QFontMetrics(m_font);
-        m_rows = (height() - 10) / m_metrics->ascent ();
+        m_rows = (height() - 3) / m_metrics->height ();
         updateList();
+        if(m_popupWidget)
+        {
+            m_popupWidget->deleteLater();
+            m_popupWidget = 0;
+        }
     }
     else
     {
-        m_update = TRUE;
+        m_update = true;
         m_metrics = new QFontMetrics(m_font);
     }
+    if(show_popup)
+        m_popupWidget = new PlayListPopup::PopupWidget(this);
 }
 
 void ListWidget::loadColors()
@@ -97,7 +107,6 @@ void ListWidget::loadColors()
 
 void ListWidget::paintEvent(QPaintEvent *)
 {
-
     QPainter m_painter(this);
     //m_painter.setPen(Qt::white);
     m_painter.setFont(m_font);
@@ -110,8 +119,8 @@ void ListWidget::paintEvent(QPaintEvent *)
         {
             m_painter.setBrush(QBrush(m_selected_bg));
             m_painter.setPen(m_selected_bg);
-            m_painter.drawRect ( 6, 15+(i-1)*m_metrics->ascent(),
-                                 width() - 10, m_metrics->ascent());
+            m_painter.drawRect ( 6, 15+(i-1)*m_metrics->height() + 2,
+                                 width() - 10, m_metrics->height());
         }
 
         if (m_model->currentRow() == i + m_first)
@@ -119,7 +128,7 @@ void ListWidget::paintEvent(QPaintEvent *)
         else
             m_painter.setPen(m_normal);  //243,58
 
-        m_painter.drawText(10,14+i*m_metrics->ascent(),m_titles.at(i));
+        m_painter.drawText(10,14+i*m_metrics->height(),m_titles.at(i));
 
         if (m_model->isQueued(m_model->item(i + m_first)) ||
                 (m_player->isRepeatable() && (m_model->currentRow() == m_first + i)) || m_show_protocol)
@@ -131,14 +140,14 @@ void ListWidget::paintEvent(QPaintEvent *)
             m_painter.setFont(m_font);
 
             m_painter.drawText(width() - 10 - m_metrics->width(extra_string) - m_metrics->width(m_times.at(i)),
-                               14+i*m_metrics->ascent (), extra_string);
+                               14+i*m_metrics->height (), extra_string);
             m_font.setPointSize(old_size);
             m_painter.setFont(m_font);
             m_painter.setBrush(QBrush(m_normal_bg));
         }
 
         m_painter.drawText(width() - 7 - m_metrics->width(m_times.at(i)),
-                           14+i*m_metrics->ascent (), m_times.at(i));
+                           14+i*m_metrics->height (), m_times.at(i));
     }
 
 }
@@ -158,7 +167,9 @@ void ListWidget::mouseDoubleClickEvent (QMouseEvent *e)
 
 void ListWidget::mousePressEvent(QMouseEvent *e)
 {
-    m_scroll = TRUE;
+    if(m_popupWidget)
+        m_popupWidget->hide();
+    m_scroll = true;
     int y = e->y();
     int row = rowAt(y);
 
@@ -170,7 +181,7 @@ void ListWidget::mousePressEvent(QMouseEvent *e)
             m_model->clearSelection();
 
         if (m_model->isSelected(row) && (e->modifiers() == Qt::NoModifier))
-            m_select_on_release = TRUE;
+            m_select_on_release = true;
 
         //qWarning("m_prev_clicked_row: %d",m_prev_clicked_row);
 
@@ -180,19 +191,11 @@ void ListWidget::mousePressEvent(QMouseEvent *e)
 
             if (m_pressed_row > m_anchor_row)
             {
-                //int upper_selected = m_model->firstSelectedUpper(m_anchor_row);
-                //if (INVALID_ROW != upper_selected)
-                //{
-                /*for (int j = upper_selected;j < m_anchor_row;j++)
-                {
-                 m_model->setSelected(j, false);
-                }*/
                 m_model->clearSelection();
                 for (int j = m_anchor_row;j <= m_pressed_row;j++)
                 {
                     m_model->setSelected(j, true);
                 }
-                //}
             }
             else
             {
@@ -202,27 +205,6 @@ void ListWidget::mousePressEvent(QMouseEvent *e)
                     m_model->setSelected(j, true);
                 }
             }
-
-            /*
-                   int upper_selected = m_model->firstSelectedUpper(row);
-                   int lower_selected = m_model->firstSelectedLower(row);
-                   if (INVALID_ROW != upper_selected)
-                   {
-                       for (int j = upper_selected;j <= row;j++)
-                       {
-                           m_model->setSelected(j, true);
-                       }
-                   }
-                   else if (INVALID_ROW != lower_selected)
-                   {
-                       for (int j = row;j <= lower_selected;j++)
-                       {
-                           m_model->setSelected(j, true);
-                       }
-                   }
-                   else
-                       m_model->setSelected(row, true);
-            */
         }
         else
         {
@@ -241,10 +223,8 @@ void ListWidget::mousePressEvent(QMouseEvent *e)
 
 void ListWidget::resizeEvent(QResizeEvent *e)
 {
-    m_rows = (e->size().height() - 10) / m_metrics->ascent ();
-
-    m_scroll = TRUE;
-
+    m_rows = (e->size().height() - 3) / m_metrics->height ();
+    m_scroll = true;
     updateList();
     QWidget::resizeEvent(e);
 }
@@ -263,10 +243,33 @@ void ListWidget::wheelEvent (QWheelEvent *e)
     if (m_first > m_model->count() - m_rows)
         m_first = m_model->count() - m_rows;
 
-    m_scroll = FALSE;
+    m_scroll = false;
     updateList();
 }
 
+bool ListWidget::event (QEvent *e)
+{
+    if(m_popupWidget)
+    {
+        if(e->type() == QEvent::ToolTip)
+        {
+            QHelpEvent *helpEvent = (QHelpEvent *) e;
+            int row = rowAt(helpEvent->y());
+            if(row < 0)
+            {
+                m_popupWidget->deactivate();
+                return QWidget::event(e);
+            }
+            e->accept();
+            m_popupWidget->prepare(m_model->item(row), helpEvent->globalPos());
+            return true;
+        }
+        else if(e->type() == QEvent::Leave)
+            m_popupWidget->deactivate();
+    }
+    return QWidget::event(e);
+}
+
 void ListWidget::updateList()
 {
     if (m_model->count() < (m_rows+m_first+1) && m_rows< m_model->count())
@@ -279,20 +282,16 @@ void ListWidget::updateList()
         emit positionChanged(0,0);
     }
     else
-    {
-        //int pos = m_first*99/(m_model->count() - m_rows);
-        //emit positionChanged(pos);
         emit positionChanged(m_first, m_model->count() - m_rows);
-    }
     if (m_model->count() <= m_first)
     {
         m_first = 0;
         emit positionChanged(0, qMax(0, m_model->count() - m_rows));
     }
 
-    m_titles = m_model->getTitles(m_first, m_rows );
-    m_times  = m_model->getTimes(m_first, m_rows );
-    m_scroll = FALSE;
+    m_titles = m_model->getTitles(m_first, m_rows);
+    m_times  = m_model->getTimes(m_first, m_rows);
+    m_scroll = false;
     //add numbers
     for (int i = 0; i < m_titles.size() && m_show_number; ++i)
     {
@@ -302,7 +301,7 @@ void ListWidget::updateList()
     }
     //elide title
     QString extra_string;
-    for (int i=0; i<m_titles.size(); ++i )
+    for (int i=0; i<m_titles.size(); ++i)
     {
         extra_string = getExtraString(m_first + i);
         int extra_string_space = extra_string.isEmpty() ? 0 : m_metrics->width(extra_string);
@@ -312,12 +311,40 @@ void ListWidget::updateList()
     update();
 }
 
-void ListWidget::setModel(PlayListModel *model)
+void ListWidget::autoscroll()
 {
-    m_model = model;
-    connect (m_model, SIGNAL(listChanged()), SLOT(updateList()));
-    connect (m_model, SIGNAL(currentChanged()), SLOT(recenterCurrent()));
+    SimpleSelection sel = m_model->getSelection(m_pressed_row);
+    if ((sel.m_top == 0 && m_scroll_direction == TOP && sel.count() > 1) ||
+        (sel.m_bottom == m_model->count() - 1 && m_scroll_direction == DOWN && sel.count() > 1))
+        return;
+
+    if(m_scroll_direction == DOWN)
+    {
+        int row = m_first + m_rows;
+        (m_first + m_rows < m_model->count()) ? m_first ++ : m_first;
+        m_model->moveItems(m_pressed_row,row);
+        m_pressed_row = row;
+    }
+    else if(m_scroll_direction == TOP && m_first > 0)
+    {
+        m_first --;
+        m_model->moveItems(m_pressed_row, m_first);
+        m_pressed_row = m_first;
+    }
+}
+
+void ListWidget::setModel(PlayListModel *selected, PlayListModel *previous)
+{
+    if(previous)
+        disconnect(previous, 0, this, 0); //disconnect previous model
+    qApp->processEvents();
+    m_model = selected;
+    m_first = 0;
+    m_scroll = false;
+    recenterCurrent();
     updateList();
+    connect (m_model, SIGNAL(currentChanged()), SLOT(recenterCurrent()));
+    connect (m_model, SIGNAL(listChanged()), SLOT(updateList()));
 }
 
 void ListWidget::scroll(int sc)
@@ -325,7 +352,7 @@ void ListWidget::scroll(int sc)
     if (m_model->count() <= m_rows)
         return;
     m_first = sc; //*(m_model->count() - m_rows)/99;
-    m_scroll = TRUE;
+    m_scroll = true;
     updateList();
 }
 
@@ -357,7 +384,6 @@ void ListWidget::dropEvent(QDropEvent *event)
                 processFileInfo(QFileInfo(add_string));
         }
     }
-
 }
 
 void ListWidget::processFileInfo(const QFileInfo& info)
@@ -394,65 +420,84 @@ const QString ListWidget::getExtraString(int i)
 
 void ListWidget::mouseMoveEvent(QMouseEvent *e)
 {
-    m_scroll = true;
-    if (m_prev_y > e->y())
-        m_scroll_direction = TOP;
-    else if (m_prev_y < e->y())
-        m_scroll_direction = DOWN;
-    else
-        m_scroll_direction = NONE;
-
-    int row = rowAt(e->y());
-
-    if (INVALID_ROW != row)
+    if(e->buttons() == Qt::LeftButton)
     {
-        SimpleSelection sel = m_model->getSelection(m_pressed_row);
-        if (((sel.m_top == 0 && m_scroll_direction == TOP) && sel.count() > 1) ||
-                (sel.m_bottom == m_model->count() - 1 && m_scroll_direction == DOWN && sel.count() > 1)
-           )
+        m_scroll = true;
+        if (m_prev_y > e->y())
+            m_scroll_direction = TOP;
+        else if (m_prev_y < e->y())
+            m_scroll_direction = DOWN;
+        else
+            m_scroll_direction = NONE;
+
+        if(e->y() < 0 || e->y() > height())
+        {
+            if(!m_timer->isActive())
+                m_timer->start();
             return;
+        }
+        m_timer->stop();
 
-        if (row + 1 == m_first + m_rows && m_scroll_direction == DOWN)
-            (m_first + m_rows < m_model->count() ) ? m_first ++ : m_first;
-        else if (row == m_first && m_scroll_direction == TOP)
-            (m_first > 0)  ? m_first -- : 0;
+        int row = rowAt(e->y());
 
-        m_model->moveItems(m_pressed_row,row);
-        m_prev_y = e->y();
-        m_scroll = false;
-        m_pressed_row = row;
+        if (INVALID_ROW != row)
+        {
+            SimpleSelection sel = m_model->getSelection(m_pressed_row);
+            if(sel.count() > 1 && m_scroll_direction == TOP)
+            {
+                if(sel.m_top == 0 || sel.m_top == m_first)
+                    return;
+            }
+            else if(sel.count() > 1 && m_scroll_direction == DOWN)
+            {
+                if(sel.m_bottom == m_model->count() - 1 || sel.m_bottom == m_first + m_rows)
+                    return;
+            }
+            m_model->moveItems(m_pressed_row,row);
+
+            m_prev_y = e->y();
+            m_scroll = false;
+            m_pressed_row = row;
+        }
+    }
+    else if(m_popupWidget)
+    {
+        int row = rowAt(e->y());
+        if(row < 0 || m_popupWidget->item() != m_model->item(row))
+            m_popupWidget->deactivate();
     }
 }
 
 void ListWidget::mouseReleaseEvent(QMouseEvent *e)
 {
-    if (FALSE != m_select_on_release)
+    if (false != m_select_on_release)
     {
         m_model->clearSelection();
         m_model->setSelected(m_pressed_row,true);
         //if(e->modifiers() != Qt::ShiftModifier)
         m_anchor_row = m_pressed_row;
-        m_select_on_release = FALSE;
+        m_select_on_release = false;
     }
     m_pressed_row = INVALID_ROW;
     m_scroll_direction = NONE;
+    m_timer->stop();
+    m_scroll = false;
     QWidget::mouseReleaseEvent(e);
 }
 
-int ListWidget::rowAt( int y) const
+int ListWidget::rowAt(int y) const
 {
     if (y <= 14 && y >= 2 && m_model->count())
         return m_first;
 
-    for (int i = 0; i < qMin(m_rows, m_model->count() - m_first); ++i )
+    for (int i = 0; i < qMin(m_rows, m_model->count() - m_first) - 1; ++i)
     {
-        if ((y >= 14 + i * m_metrics->ascent ()) && (y <= 14 + (i+1) * m_metrics->ascent()))
+        if ((y >= 14 + i * m_metrics->height ()) && (y <= 14 + (i+1) * m_metrics->height()))
             return m_first + i + 1;
     }
     return INVALID_ROW;
 }
 
-
 void ListWidget::contextMenuEvent(QContextMenuEvent * event)
 {
     if (menu())
@@ -461,12 +506,12 @@ void ListWidget::contextMenuEvent(QContextMenuEvent * event)
 
 void ListWidget::recenterCurrent()
 {
-    if (!m_scroll)
+    if (!m_scroll && m_rows)
     {
         if (m_first + m_rows < m_model->currentRow() + 1)
             m_first = qMin(m_model->count() - m_rows,
-                           m_model->currentRow() - m_rows/2 + 1);
+                           m_model->currentRow() - m_rows/2);
         else if (m_first > m_model->currentRow())
-            m_first = qMax (m_model->currentRow() - m_rows/2 + 1, 0);
+            m_first = qMax (m_model->currentRow() - m_rows/2, 0);
     }
 }
