@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ilya Kotov                                      *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,20 +24,23 @@
 #include <QDir>
 #include <QContextMenuEvent>
 
-/**
-   @author Ilya Kotov <forkotov02@hotmail.ru>
-*/
 class QFont;
 class QFontMetrics;
 class QMenu;
 class QAction;
-
+class QTimer;
 class PlayList;
 class PlayListModel;
 class Skin;
 class PlayListItem;
 class MediaPlayer;
+namespace PlayListPopup{
+class PopupWidget;
+}
 
+/**
+   @author Ilya Kotov <forkotov02@hotmail.ru>
+*/
 class ListWidget : public QWidget
 {
     Q_OBJECT
@@ -46,7 +49,6 @@ public:
 
     ~ListWidget();
 
-    void setModel(PlayListModel *);
     void readSettings();
     /*!
      * Returns count of currently visible rows.
@@ -74,15 +76,24 @@ public:
         m_anchor_row = r;
     }
 
+    QMenu *menu()
+    {
+        return m_menu;
+    }
+
+    PlayListModel *model()
+    {
+        Q_ASSERT(!m_model);
+        return m_model;
+    }
+
+
 public slots:
     void updateList();
     void scroll(int); //0-99
     void recenterCurrent();
+    void setModel(PlayListModel *selected, PlayListModel *previous = 0);
 
-    QMenu *menu()
-    {
-        return m_menu;
-    };
 
 signals:
     void selectionChanged();
@@ -99,10 +110,12 @@ protected:
     int rowAt(int)const;
     void dragEnterEvent(QDragEnterEvent *event);
     void dropEvent(QDropEvent *event);
-    void contextMenuEvent ( QContextMenuEvent * event );
+    void contextMenuEvent (QContextMenuEvent * event);
+    bool event (QEvent *e);
 
 private slots:
     void updateSkin();
+    void autoscroll();
 
 private:
     void loadColors();
@@ -140,6 +153,8 @@ private:
     bool m_show_protocol;
     bool m_show_number;
     MediaPlayer *m_player;
+    PlayListPopup::PopupWidget *m_popupWidget;
+    QTimer *m_timer;
 };
 
 #endif
