@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,21 +21,16 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
-
+#include <QPointer>
 #include <qmmp/output.h>
 #include <qmmp/decoder.h>
 #include <qmmp/decoderfactory.h>
 #include <qmmpui/playlistitem.h>
-
 #include "display.h"
 #include "titlebar.h"
 
-/**
-   @author Ilya Kotov <forkotov02@hotmail.ru>
-*/
 class PlayList;
-class PlayListModel;
-class ConfigDialog;
+class PlayListManager;
 class EqWidget;
 class MainVisual;
 class Skin;
@@ -44,12 +39,13 @@ class JumpToTrackDialog;
 class VisualMenu;
 class GeneralHandler;
 class MediaPlayer;
-
 class QMenu;
 class QKeyEvent;
 class BuiltinCommandLineOption;
 
-
+/**
+   @author Ilya Kotov <forkotov02@hotmail.ru>
+*/
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
@@ -82,53 +78,42 @@ public slots:
     void addFile();
     void addUrl();
 
-    void newPlaylist();
     void loadPlaylist();
     void savePlaylist();
-
     void setFileList(const QStringList&);
+    void about();
 
 protected:
-    virtual  void closeEvent ( QCloseEvent *);
-    virtual  void changeEvent ( QEvent * event );
-    virtual void keyPressEvent ( QKeyEvent* );
+    virtual void closeEvent (QCloseEvent *);
+    virtual void changeEvent (QEvent *event);
+    virtual void keyPressEvent (QKeyEvent* );
 
 private slots:
     void showState(Qmmp::State state);
     void showMetaData();
-    void clear();
-    void startSeek();
-    void endSeek();
     void showSettings();
     void updateEQ();
     void forward();
     void backward();
-    void about();
     void handleCloseRequest();
 
 private:
     void readSettings();
     void writeSettings();
     void createActions();
-    bool seeking;
+    void resume();
     SoundCore *m_core;
     QMenu *m_mainMenu;
-    MainDisplay *display;
+    MainDisplay *m_display;
     PlayList *m_playlist;
-    PlayListModel *m_playListModel;
-    TitleBar *m_titlebar;
-    ConfigDialog *m_confDialog;
+    PlayListManager *m_pl_manager;
+    QPointer <PlayListModel> m_model;
     int m_preamp;
     EqWidget *m_equalizer;
     MainVisual *m_vis;
     QString m_lastDir;
     bool m_update;
-    bool m_showMessage;
-    int m_messageDelay;
-    bool m_paused;
-    bool m_showToolTip;
     Skin *m_skin;
-    QString m_playlistName;
     JumpToTrackDialog* m_jumpDialog;
     bool m_hideOnClose, m_startHidden;
     VisualMenu *m_visMenu;
