@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ilya Kotov                                      *
+ *   Copyright (C) 2006-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,15 +21,9 @@
 #define PLAYLIST_H
 
 #include <QWidget>
+#include <QPointer>
 
-class KeyboardManager;
-
-/**
-   @author Ilya Kotov <forkotov02@hotmail.ru>
-*/
-
-class QMenu;
-
+class QMenu;;
 class Skin;
 class ListWidget;
 class PlayListItem;
@@ -42,20 +36,29 @@ class SymbolDisplay;
 class OutputState;
 class PixmapWidget;
 class PlaylistControl;
+class KeyboardManager;
+class PlayListManager;
+class PlayListBrowser;
+class PlayListSelector;
 
+/**
+   @author Ilya Kotov <forkotov02@hotmail.ru>
+*/
 class PlayList : public QWidget
 {
         Q_OBJECT
     public:
-        PlayList ( QWidget *parent = 0 );
+        PlayList (PlayListManager *manager, QWidget *parent = 0);
 
         ~PlayList();
-        void load ( PlayListItem * );
-        void setModel ( PlayListModel * );
+        void load (PlayListItem *);
         void readSettings();
-        //void setInfo ( const OutputState &,int,int );
         PlayListItem *currentItem();
-        ListWidget* listWidget() const{return m_listWidget;}
+        ListWidget* listWidget() const
+        {
+            return m_listWidget;
+        }
+        void setMinimalMode(bool b = true);
 
     signals:
         void play();
@@ -66,7 +69,6 @@ class PlayList : public QWidget
         void eject();
         void loadPlaylist();
         void savePlaylist();
-        void newPlaylist();
         void closed();
 
     public slots:
@@ -79,11 +81,14 @@ class PlayList : public QWidget
         void showSelectMenu();
         void showSortMenu();
         void showPlaylistMenu();
-
+        void updateSkin();
+        void deletePlaylist();
+        void showPlayLists();
 
     private:
-        QString formatTime ( int sec );
-        void drawPixmap ( int, int );
+        void updatePositions();
+        QString formatTime (int sec);
+        void drawPixmap (int, int);
         void writeSettings();
         void createMenus();
         void createActions();
@@ -92,6 +97,7 @@ class PlayList : public QWidget
         QMenu *m_selectMenu;
         QMenu *m_sortMenu;
         QMenu *m_playlistMenu;
+        QWidget *m_resizeWidget;
         Button *m_buttonAdd;
         Button *m_buttonSub;
         Button *m_selectButton;
@@ -104,25 +110,29 @@ class PlayList : public QWidget
 
         Skin *m_skin;
         ListWidget *m_listWidget;
-        PlayListModel *m_playListModel;
         PlayListTitleBar *m_titleBar;
         PlayListSlider *m_plslider;
         QList <QAction *> m_actions;
         QPoint m_pos;
         bool m_resize;
         bool m_update;
-        int m_anchor_row;
+        int m_ratio;
+        int m_height;
+        bool m_shaded;
+        PlayListManager *m_pl_manager;
         KeyboardManager* m_keyboardManager;
+        QPointer <PlayListBrowser> m_pl_browser;
+        PlayListSelector *m_pl_selector;
 
     protected:
-        virtual void paintEvent ( QPaintEvent * );
-        virtual void resizeEvent ( QResizeEvent * );
-        virtual void mouseMoveEvent ( QMouseEvent * );
-        virtual void mousePressEvent ( QMouseEvent * );
-        virtual void mouseReleaseEvent ( QMouseEvent * );
-        virtual void changeEvent ( QEvent* );
-        virtual void closeEvent ( QCloseEvent* );
-        virtual void keyPressEvent ( QKeyEvent* );
+        virtual void paintEvent (QPaintEvent *);
+        virtual void resizeEvent (QResizeEvent *);
+        virtual void mouseMoveEvent (QMouseEvent *);
+        virtual void mousePressEvent (QMouseEvent *);
+        virtual void mouseReleaseEvent (QMouseEvent *);
+        virtual void changeEvent (QEvent*);
+        virtual void closeEvent (QCloseEvent*);
+        virtual void keyPressEvent (QKeyEvent*);
 };
 
 #endif
