@@ -28,7 +28,7 @@ SymbolDisplay::SymbolDisplay ( QWidget *parent, int digits )
         : PixmapWidget ( parent ), m_digits ( digits ), m_text(), m_max(0)
 {
     m_alignment = Qt::AlignRight;
-    m_skin = Skin::getPointer();
+    m_skin = Skin::instance();
     connect ( m_skin, SIGNAL ( skinChanged() ), this, SLOT (draw()));
     draw();
     for (int i=0; i<m_digits; ++i)
